@@ -3,16 +3,16 @@
  *
  * Exported definitions for the plow module.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  *
  * rcsid $Header: /usr/cvsroot/magic-8.0/plow/plow.h,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $
@@ -26,7 +26,8 @@
 /* Technology file clients */
 extern int PlowTechInit(), PlowTechFinal();
 extern bool PlowTechLine();
-extern void PlowAfterTech();
+extern int PlowDRCInit(), PlowDRCFinal();
+extern bool PlowDRCLine();
 
 /* Called by CmdPlow() */
 extern bool Plow();
@@ -34,6 +35,8 @@ extern bool Plow();
 /* Debugging command procedure */
 extern int PlowTest();
 
+extern void PlowExtendJogHorizon();
+
 /* Exported tile type masks */
 extern TileTypeBitMask PlowFixedTypes;		/* Non-stretchable types */
 extern TileTypeBitMask PlowContactTypes;	/* Contact types */
@@ -51,4 +54,9 @@ extern int PlowJogHorizon;
 /* TRUE if we should eliminate jogs after each plow operation */
 extern bool PlowDoStraighten;
 
+/* C99 compat */
+extern void DRCPlowScale();
+extern void PlowInit();
+extern void PlowAfterTech();
+
 #endif /* _PLOW_H */
